summaryrefslogtreecommitdiffstats
path: root/widget/windows/nsDataObj.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'widget/windows/nsDataObj.cpp')
-rw-r--r--widget/windows/nsDataObj.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/widget/windows/nsDataObj.cpp b/widget/windows/nsDataObj.cpp
index 88a2a2ad09..60e2784f37 100644
--- a/widget/windows/nsDataObj.cpp
+++ b/widget/windows/nsDataObj.cpp
@@ -346,10 +346,10 @@ HRESULT nsDataObj::CreateStream(IStream** outStream) {
pStream->AddRef();
// query the requestingPrincipal from the transferable and add it to the new
// channel
nsCOMPtr<nsIPrincipal> requestingPrincipal =
- mTransferable->GetRequestingPrincipal();
+ mTransferable->GetDataPrincipal();
MOZ_ASSERT(requestingPrincipal, "can not create channel without a principal");
// Note that the cookieJarSettings could be null if the data object is for the
@@ -346,10 +346,10 @@ HRESULT nsDataObj::CreateStream(IStream** outStream) {
pStream->AddRef();
- // query the requestingPrincipal from the transferable and add it to the new
- // channel
+ // query the dataPrincipal from the transferable and add it to the new
+ // channel.
nsCOMPtr<nsIPrincipal> requestingPrincipal =